@@ -418,7 +418,6 @@ sub __flow_sql__ {
     my $params   = shift;    #[array]
     my $bulk     = shift;
     my $one_page = shift;
-
     my $dbh   = $self->_dbh();
     my $field = $self->_key_field;
     my $page  = $one_page || 0;
@@ -429,7 +428,7 @@ sub __flow_sql__ {
         my $res = $dbh->selectcol_arrayref( $query_limit, {}, @$params );
         $count = scalar(@$res);
         $flow_res =
-          $flow->flow( map { $self->after_load( { $field => $_ } )->{$field} }
+          $flow->_flow( map { $self->after_load( { $field => $_ } )->{$field} }
               @$res );
         $page++;
 
@@ -452,6 +451,7 @@ params:
  desc - revert sorting ([1,0])
  where -  custom where if needed, instead expr ['where sring', $query_param1,..]
  query - custom query
+ uniq - set uniq flag ( eq GROUP BY (key) )
 
 return:
     [array] - array of ids
@@ -490,6 +490,10 @@ sub list_ids {
     my $field      = $self->_key_field;
     my $query      = $args{query} || "SELECT $field FROM $table_name";
     $query .= " where $where" if $where;
+    if ($args{uniq}) {
+      #strip dups
+      $query .= " group by $field";
+    }
     my $onpage = $args{onpage} || 10000;
 
     #add order by
